@@ -3,7 +3,7 @@ BEGIN {
   $OX::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $OX::VERSION = '0.05';
+  $OX::VERSION = '0.06';
 }
 use Moose::Exporter;
 use 5.010;
@@ -19,7 +19,7 @@ use Scalar::Util 'blessed';
 my ($import, undef, $init_meta) = Moose::Exporter->build_import_methods(
     also      => ['Moose', 'Bread::Board::Declare'],
     with_meta => [qw(router route mount wrap)],
-    as_is     => [qw(as)],
+    as_is     => [qw(as literal)],
     install   => [qw(unimport)],
     class_metaroles => {
         class => ['OX::Meta::Role::Class'],
@@ -87,10 +87,11 @@ sub route {
 
     my ($class, $route_spec) = $meta->route_builder_for($action_spec);
     $meta->add_route(
-        path       => $path,
-        class      => $class,
-        route_spec => $route_spec,
-        params     => \%params,
+        path                => $path,
+        class               => $class,
+        route_spec          => $route_spec,
+        params              => \%params,
+        definition_location => $meta->name,
     );
 }
 
@@ -98,9 +99,14 @@ sub route {
 sub mount {
     my ($meta, $path, $mount, %params) = @_;
 
+    my %default = (
+        path                => $path,
+        definition_location => $meta->name,
+    );
+
     if (!ref($mount)) {
         $meta->add_mount(
-            path         => $path,
+            %default,
             class        => $mount,
             dependencies => \%params,
         );
@@ -110,14 +116,14 @@ sub mount {
             unless $mount->can('to_app');
 
         $meta->add_mount(
-            path => $path,
-            app  => $mount->to_app,
+            %default,
+            app => $mount->to_app,
         );
     }
     elsif (ref($mount) eq 'CODE') {
         $meta->add_mount(
-            path => $path,
-            app  => $mount,
+            %default,
+            app => $mount,
         )
     }
     else {
@@ -136,9 +142,19 @@ sub wrap {
 }
 
 
+sub literal {
+    my ($value) = @_;
+    return Bread::Board::Literal->new(
+        name  => '__ANON__',
+        value => $value,
+    );
+}
+
+
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -147,7 +163,7 @@ OX - the hardest working two letters in Perl
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -259,13 +275,15 @@ used in place of the previously mentioned list.
       foo => 'some_service',
   );
 
-  router My::Custom::Router->new(%router_args);
+  router(My::Custom::Router->new(%router_args));
 
 If you have declared a router manually elsewhere, you can pass in either the
 class name or the built router object to C<router> instead of a block. It will
 be used directly in that case. If you pass a class name, it can take an
 optional hash of dependencies, which will be resolved and passed into the
-class's constructor as arguments.
+class's constructor as arguments. Note that parentheses are required if the
+argument is a literal constructor call, to avoid it being parsed as an indirect
+method call.
 
 =head2 route $path, $action_spec, %params
 
@@ -359,7 +377,7 @@ statement corresponds to the outermost middleware (just like
 L<Plack::Builder>).
 
   wrap 'Plack::Middleware::Static' => (
-      path => dep(value => sub { s{^/static/}{} }),
+      path => literal(sub { s{^/static/}{} }),
       root => 'static_root',
   );
 
@@ -369,11 +387,12 @@ them into the constructor) and call C<wrap> on that instance, passing in the
 application coderef so far and using the result as the new application (this is
 the API provided by L<Plack::Middleware>).
 
-  wrap Plack::Middleware::StackTrace->new(force => 1);
+  wrap(Plack::Middleware::StackTrace->new(force => 1));
 
 If you specify an object as the middleware, it will call C<wrap> on that
 object, passing in the application coderef so far and use the result as the new
-application.
+application. Note that parentheses are required if the argument is a literal
+constructor call, to avoid it being parsed as an indirect method call.
 
   wrap sub {
       my $app = shift;
@@ -388,6 +407,19 @@ application.
 If you specify a coderef as the middleware, it will call that coderef, passing
 in the application coderef so far, and use the result as the new application.
 
+=head2 literal
+
+  wrap 'Plack::Middleware::Static', (
+      path => literal(qr{^/(images|js|css)/}),
+      root => 'static_root',
+  );
+
+The C<literal> keyword allows you to declare dependencies on literal values,
+rather than services. This is useful for situations where the constructor
+values aren't user-configurable, but are inherent to your app's structure, such
+as the C<path> option to L<Plack::Middleware::Static>, or the C<subrequest>
+option to L<Plack::Middleware::ErrorDocument>.
+
 =head1 BUGS
 
 No known bugs.
@@ -453,4 +485,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
